/**
 * 页面容器组件，页头、身体、页脚三部分组成
 */
import React, {Component} from 'react'
import PropTypes from 'prop-types'
import {withRouter} from 'react-router'
import {Icon, NavBar} from 'antd-mobile'
import './styles/Page.scss'

/**
 * 页面头部导航栏
 */
class PageHead extends Component {
  back = () => {
    const {backLevel, isIndex, router} = this.props;
    if (isIndex) {
      return;
    }
    if (backLevel) {
      router.go(-1 * backLevel);
    } else {
      router.goBack();
    }
  };

  onLeftClick = () => {
    const {beforeBack} = this.props;
    if (beforeBack) {
      beforeBack(this.back);
    } else {
      this.back();
    }
  };

  render() {
    const {title, isIndex, onRightClick} = this.props;
    return (
      <NavBar
        mode='dark'
        icon={isIndex ? '' : <Icon type='left' size='lg' className='zk_navbar-hd_margin'/>}
        leftContent={isIndex ? '' : <div className='zk_navbar-hd_margin'>返回</div>}
        onLeftClick={this.onLeftClick}
        rightContent={
          onRightClick ? <Icon key='1' type='ellipsis' onClick={onRightClick}/> : ''}
      >
        {title}
      </NavBar>
    )
  }
}

/**
 * 页脚部分
 */
class PageFoot extends Component {
  render() {
    return (
      <div>
        {this.props.foot}
      </div>
    )
  }
}

/**
 * 页面布局
 */
class Page extends Component {
  render() {
    const {title, isIndex, router, backLevel, onRightClick, foot, children, beforeBack, className} = this.props;
    const pageClassName = className ? className + " zk_page-bd_bg" : "zk_page-bd_bg";
    return (
      <div className='zk-page zk_div-animation'>
        {title ?
          <PageHead
            title={title}
            isIndex={isIndex}
            router={router}
            backLevel={backLevel}
            onRightClick={onRightClick}
            beforeBack={beforeBack}
          /> : ''}
        <div className={pageClassName}>
          {children}
        </div>
        <PageFoot foot={foot}/>
      </div>
    );
  }
}

Page.propTypes = {
  // 页面标题
  title: PropTypes.string,
  // 是否是首页
  isIndex: PropTypes.bool,
  // 导航栏右侧功能按钮点击事件
  onRightClick: PropTypes.func,
  // 返回的层级
  backLevel: PropTypes.number,
  // 样式类名称
  className: PropTypes.string,
  // 底部内容
  foot: PropTypes.element
};
export default withRouter(Page)
