/**
 * 饼状图组件
 */
import React, {Component} from 'react'
import PropTypes from 'prop-types'
import ReactEcharts from 'echarts-for-react';

class Pie extends Component {
  loading = null;
  time = 3000;
  radiusArr = [[0, '45%'],['20%', '45%']];
  radius = this.radiusArr[0];
  textColor = '#2983c7';
  colors = ['#3fb1e3', '#6be6c1', '#626c91', '#a0a7e6', '#c4ebad', '#96dee8'];
  onChartReady = (chart) => {
    this.loading = setTimeout(function () {
      chart.hideLoading();
    }, this.time);
    console.log('echarts is ready');
  };
  getOption = () => {
    const {data, title, labelFormatter} = this.props;
    return {
      color: this.colors,
      title: {
        text: title,
        x: 'center',
        textStyle: {
          color: this.textColor,
          fontWeight: 'normal'
        }
      },
      tooltip: {
        trigger: 'item',
        formatter: "{a} <br/>{b} : {c} ({d}%)"
      },
      legend: {
        type: 'scroll',
        orient: 'vertical',
        top: 'middle',
        right: 'right',
        data: data.map((item) => {
          return item.name
        }),
        textStyle: {color: this.textColor}
      },
      series: [
        {
          name: title,
          type: 'pie',
          radius: this.radius,
          center: ['45%', '50%'],
          label: {
            normal: {
              formatter: labelFormatter
            }
          },
          selectedMode: 'single',
          data: data,
          itemStyle: {
            emphasis: {
              shadowBlur: 10,
              shadowOffsetX: 0,
              shadowColor: 'rgba(0, 0, 0, 0.5)'
            }
          }
        }
      ]
    }
  };
  getLoadingOption = () => {
    return {
      text: '加载中...',
      color: '#000',
      textColor: '#000',
      maskColor: '#fff',
    };
  };

  constructor(props) {
    super(props);
    const {type} = this.props;
    if (type === '环形图') {
      this.radius = this.radiusArr[1];
    }
    this.state={
      showLoading : true,
    }
  }

  componentWillUnmount() {
    clearTimeout(this.loading);
  }

  componentWillReceiveProps(nextProps){
    this.onChartReady(this.echarts_react.getEchartsInstance());
    this.setState({
      display:'block',
      showLoading:false
    });
  }
  handleData=(data)=>{
    let body = '';
    if(data.length === 0){
      body =<div className='zk_div-echars_nodata' style={{display:this.state.display}}>无数据</div>;
    }
    return body;
  };

  render() {
    const {data} = this.props;
    let body = this.handleData(data);
    return (
      <div style={{position:'relative'}}>
      <ReactEcharts
        ref={(e) => { this.echarts_react = e; }}
        option={this.getOption()}
        loadingOption={this.getLoadingOption()}
        onChartReady={this.onChartReady}
        showLoading={this.state.showLoading}
        className={this.props.className}
      />
        {body}
      </div>
    )
  }
}

Pie.propTypes = {
  // 数据
  data: PropTypes.array.isRequired,
  // 标题
  title: PropTypes.string,
  // 饼状图类型：'饼状图'|'环形图'
  type: PropTypes.string,
  // 引导线上文本格式
  labelFormatter: PropTypes.string,
  // 容器样式类
  className: PropTypes.string,
};
export default Pie;
