/**
 * 带搜座框的列表组件，可对列表中符合检索条件的列表项进行筛选和查询
 */
import React, {Component} from 'react'
import PropTypes from 'prop-types'
import {SearchBar} from 'antd-mobile'
import ListView from '../ListView'
import './styles/SearchListView.scss'

/**
 * 带搜索框的列表组件
 */
class SearchListView extends Component {
  onSetPlaceholder = (value) => {
    this.setState({
      placeholder: value === 'focus' ? '' : (this.props.placeholder || '请输入')
    })
  }

  constructor(props) {
    super(props);
    this.state = {
      placeholder: this.props.placeholder || '请输入'
    }
  }

  render() {
    const {value, onSubmit, onChange, onClear} = this.props;
    return (
      <div className='zk_searchlistview'>
        <div className='zk_searchlistview-hd'>
          <SearchBar
            placeholder={this.state.placeholder}
            value={value}
            onSubmit={onSubmit}
            onClear={onClear}
            onChange={onChange}
            onFocus={() => this.onSetPlaceholder('focus')}
            onBlur={() => this.onSetPlaceholder('blur')}
          />
        </div>
        <div className='zk_searchlistview-bd'>
          <ListView {...this.props}/>
        </div>
      </div>
    )
  }
}

SearchListView.propTypes = {
  // 搜索回调方法
  onSubmit: PropTypes.func.isRequired,
  // 清空搜索框回调方法
  onClear: PropTypes.func.isRequired,
  // change 事件回调
  onChange: PropTypes.func.isRequired,
  // 搜索值
  value: PropTypes.string,
  // 搜索框placeholder
  placeholder: PropTypes.string
}
export default SearchListView;
